#! /bin/sh
# This is a simple scripts to create the devices for tipar driver,
# it should abort if you have the devfs filesystem mounted, tipar
# supports devfs so there should be no need.

rm -f /dev/tiS?


if [ ! -e /dev/.devfsd ] ; then
	echo "Devfs not mounted creating device nodes"
        mknod /dev/tiser0    c 115  8
        mknod /dev/tiser1    c 115  9
        mknod /dev/tiser2    c 115 10
	mknod /dev/tiser3    c 115 11
        chmod 0660 /dev/tiser*
	chgrp dialout /dev/tiser?
else
        echo "Hmmm, looks like you have devfs mounted"
        ln -fs /dev/ticables/ser/0 /dev/tiser0
        ln -fs /dev/ticables/ser/1 /dev/tiser1
        ln -fs /dev/ticables/ser/2 /dev/tiser2
	ln -fs /dev/ticables/ser/3 /dev/tiser3
	chmod 0660 /dev/ticables/ser/?
	chgrp dialout /dev/ticables/ser/?
fi

        ln -fs /dev/tiser0 /dev/tiS0
        ln -fs /dev/tiser1 /dev/tiS1
        ln -fs /dev/tiser2 /dev/tiS2
        ln -fs /dev/tiser2 /dev/tiS3

echo "Nodes created"